PathItem

Struct PathItem 

pub struct PathItem {
Show 13 fields pub ref_path: Option<String>, pub get: Option<Operation>, pub post: Option<Operation>, pub put: Option<Operation>, pub patch: Option<Operation>, pub delete: Option<Operation>, pub head: Option<Operation>, pub options: Option<Operation>, pub trace: Option<Operation>, pub parameters: Option<Vec<Parameter>>, pub summary: Option<String>, pub description: Option<String>, pub servers: Option<Vec<Server>>,
}
Path Item definition (all HTTP methods for a specific path)

Fields

ref_path: Option<String>

Reference to another path item.

get: Option<Operation>

GET method

post: Option<Operation>

POST method

put: Option<Operation>

PUT method

patch: Option<Operation>

PATCH method

delete: Option<Operation>

DELETE method

head: Option<Operation>

HEAD method

options: Option<Operation>

OPTIONS method

trace: Option<Operation>

TRACE method

parameters: Option<Vec<Parameter>>

Path parameters

summary: Option<String>

Summary

description: Option<String>

Description

servers: Option<Vec<Server>>

Alternative servers for all operations in this path.

Implementations

Source

impl PathItem

pub fn try_set_operation( &mut self, method: HttpMethod, operation: Operation, ) -> Option<Operation>

Try to set an operation for a specific HTTP method.

Returns the operation that was already present, if this call replaced one.

pub fn set_operation(&mut self, method: HttpMethod, operation: Operation)

Set an operation for a specific HTTP method, discarding any replaced operation.